@@ -3,14 +3,12 @@
 from trytond.pool import PoolMeta
 from trytond.model import ModelSQL, ValueMixin, fields
 
-
-__all__ = ['Configuration', 'ConfigurationDefaultDunningProcedure', 'MoveLine']
 default_dunning_procedure = fields.Many2One(
-    'account.dunning.procedure', "Default Dunning Procedure")
+    'account.dunning.procedure', "Default Dunning Procedure",
+    help="The default dunning procedure for new customers.")
 
 
-class Configuration:
-    __metaclass__ = PoolMeta
+class Configuration(metaclass=PoolMeta):
     __name__ = 'account.configuration'
     default_dunning_procedure = fields.MultiValue(default_dunning_procedure)
 
@@ -21,8 +19,7 @@ class ConfigurationDefaultDunningProcedure(ModelSQL, ValueMixin):
     default_dunning_procedure = default_dunning_procedure
 
 
-class MoveLine:
-    __metaclass__ = PoolMeta
+class MoveLine(metaclass=PoolMeta):
     __name__ = 'account.move.line'
 
     dunnings = fields.One2Many('account.dunning', 'line', 'Dunnings')
@@ -38,5 +35,5 @@ class MoveLine:
             default = {}
         else:
             default = default.copy()
-        default.setdefault('dunnings')
+        default.setdefault('dunnings', None)
         return super(MoveLine, cls).copy(lines, default=default)
